###################################################
### chunk number 1: R-opts
###################################################
options(width=34, digits=4)


###################################################
### chunk number 2: startup
###################################################
library(diveMove)


###################################################
### chunk number 3:  eval=FALSE
###################################################
## example(diveMove)


###################################################
### chunk number 4: dives-con
###################################################
ff <- gzfile(system.file(file.path("data", "dives.csv.gz"), 
                         package="diveMove"), open="r")


###################################################
### chunk number 5: readin-csv
###################################################
srcfn <- basename(summary(ff)$description)
tdrXcsv <- read.csv(ff, sep=";")


###################################################
### chunk number 6: create-tdr
###################################################
ddtt.str <- paste(tdrXcsv$date, tdrXcsv$time)
ddtt <- strptime(ddtt.str, format="%d/%m/%Y %H:%M:%S")
time.posixct <- as.POSIXct(ddtt, tz="GMT")
tdrX <- createTDR(time=time.posixct, depth=tdrXcsv$depth,
                  concurrentData=tdrXcsv[, -c(1:3)], dtime=5,
                  file=srcfn)
## Or a TDRspeed object, since we know we have speed measurements:
tdrX <- createTDR(time=time.posixct, depth=tdrXcsv$depth,
                  concurrentData=tdrXcsv[, -c(1:3)], dtime=5,
                  file=srcfn, speed=TRUE)


###################################################
### chunk number 7: readin-tdr eval=FALSE
###################################################
## ff <- gzfile(system.file(file.path("data", "dives.csv.gz"), 
##                          package="diveMove"), open="r")
## tdrX <- readTDR(ff, speed=TRUE, sep=";", na.strings="", as.is=TRUE)
## plotTDR(tdrX)


###################################################
### chunk number 8: 
###################################################
ff <- gzfile(system.file(file.path("data", "dives.csv.gz"), 
                         package="diveMove"), open="r")
tdrX <- readTDR(ff, speed=TRUE, sep=";", na.strings="", as.is=TRUE)
png("plot_tdr.png"); plotTDR(tdrX, interact=FALSE, cex.lab=1.3); dev.off()


###################################################
### chunk number 9:  eval=FALSE
###################################################
## dcalib <- calibrateDepth(tdrX)


###################################################
### chunk number 10:  eval=FALSE
###################################################
## dcalib <- calibrateDepth(tdrX, zoc.method="offset", offset=3)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## dcalib <- calibrateDepth(tdrX, zoc.method="filter",
##                          k=c(3, 5760), probs=c(0.5, 0.02), na.rm=TRUE)


###################################################
### chunk number 12: zoc
###################################################
dcalib <- calibrateDepth(tdrX, dive.thr=3, zoc.method="offset",
                         offset=3, descent.crit.q=0.01, ascent.crit.q=0,
                         knot.factor=20)


###################################################
### chunk number 13: plot-gross-activity eval=FALSE
###################################################
## plotTDR(dcalib, concurVars=c("speed", "light"),
##         surface=TRUE)


###################################################
### chunk number 14: 
###################################################
png("plot_tdr_calibrate.png", width=380)
plotTDR(dcalib, concurVars=c("speed", "light"),
        surface=TRUE, interact=FALSE, cex.lab=1.3)
dev.off()


###################################################
### chunk number 15: plot-dive-activity eval=FALSE
###################################################
## plotTDR(dcalib, diveNo=2:8, what="phases")


###################################################
### chunk number 16: 
###################################################
png("plot_tdr_dives.png", height=380)
plotTDR(dcalib, diveNo=2:8, what="phases", interact=FALSE,
        cex.lab=1.3, depth.lim=c(0, 80))
dev.off()


###################################################
### chunk number 17: extract-dive eval=FALSE
###################################################
## extractDive(dcalib, diveNo=2:8)


###################################################
### chunk number 18: tdr-extract
###################################################
getTDR(dcalib)


###################################################
### chunk number 19: grossact1 eval=FALSE
###################################################
## getGAct(dcalib)


###################################################
### chunk number 20: grossact2 eval=FALSE
###################################################
## getGAct(dcalib, "phase.id")


###################################################
### chunk number 21: diveact-1 eval=FALSE
###################################################
## getDAct(dcalib)


###################################################
### chunk number 22: dphaselab1 eval=FALSE
###################################################
## getDPhaseLab(dcalib)
## getDPhaseLab(dcalib, 20)


###################################################
### chunk number 23: dphaselab2
###################################################
dphases <- getDPhaseLab(dcalib, c(100:300))


###################################################
### chunk number 24: diveModel eval=FALSE
###################################################
## plotDiveModel(dcalib, diveNo=260)


###################################################
### chunk number 25: 
###################################################
png("plot_dive_model.png")
plotDiveModel(dcalib, diveNo=260)
dev.off()


###################################################
### chunk number 26: extractdive
###################################################
sealX <- extractDive(dcalib, diveNo=c(100:300))
sealX


###################################################
### chunk number 27: plot-phases eval=FALSE
###################################################
## plotTDR(sealX, phaseCol=dphases)


###################################################
### chunk number 28: 
###################################################
options(width=105)


###################################################
### chunk number 29: dive-summaries
###################################################
tdrXSumm1 <- diveStats(dcalib)
names(tdrXSumm1)
tbudget <- timeBudget(dcalib, ignoreZ=TRUE)
head(tbudget, 4)
trip.labs <- stampDive(dcalib, ignoreZ=TRUE)
tdrXSumm2 <- data.frame(trip.labs, tdrXSumm1)
names(tdrXSumm2)


###################################################
### chunk number 30: 
###################################################
options(width=34, digits=4)


###################################################
### chunk number 31: calibrate-speed eval=FALSE
###################################################
## vcalib <- calibrateSpeed(dcalib, tau=0.1, contour.level=0.1,
##                          z=1, bad=c(0, 0), cex.pts=0.2)


###################################################
### chunk number 32: 
###################################################
png("speed_calibration.png")
calibrateSpeed(dcalib, tau=0.1, contour.level=0.1,
               z=1, bad=c(0, 0), cex.pts=0.2)
dev.off()


